@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.221';
+our $VERSION = '2017.222';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -51,10 +51,11 @@ sub fileSize($)
 
 sub makePath($)
  {my ($path) = @_;
-      $path =~ s/[\\\/]+\Z//;
-  return 0 if -d $path;
-  eval {make_path($path)};
-  -d $path or confess "Cannot makePath $path";
+  my @p = split //, $path; pop @p while @p and $p[-1] !~ /[\\\/]/;
+  my $p = join '', @p;
+  return 0 if -d $p;
+  eval {make_path($p)};
+  -d $p or confess "Cannot makePath $p";
   1
  }
 
@@ -103,9 +104,7 @@ sub writeFile($$)
  {my ($file, $string) = @_;
   $file or confess "No file name supplied";
   $string or carp "No string for file $file";
-  if ($file =~ /\A(.+[\\\/])/)
-   {makePath($1);
-   }
+  makePath($file);
   open my $F, ">$file" or confess "Cannot open $file for write";
   binmode($F, ":utf8");
   print  {$F} $string;
@@ -121,9 +120,7 @@ sub writeBinaryFile($$)
  {my ($file, $string) = @_;
   $file or confess "No file name supplied";
   $string or confess "No string for file $file";
-  if ($file =~ /\A(.+[\\\/])/)
-   {makePath($1);
-   }
+  makePath($file);
   open my $F, ">$file" or confess "Cannot open $file for binary write";
   binmode($F);
   print  {$F} $string;
